@@ -23,7 +23,8 @@ lbt05_main <- function(adam_db,
   assert_all_tablenames(adam_db, c("adsl", "adlb"))
   assert_string(arm_var)
   assert_string(lbl_overall, null.ok = TRUE)
-  assert_valid_variable(adam_db$adlb, c("PARAM", "AVALCAT1", "ABN_DIR"), types = list(c("character", "factor")))
+  # expand.grid steps requires levels later.
+  assert_valid_variable(adam_db$adlb, c("PARAM", "AVALCAT1", "ABN_DIR"), types = list("factor"))
   assert_valid_variable(adam_db$adlb, c("USUBJID"), types = list(c("character", "factor")), empty_ok = TRUE)
   assert_valid_variable(adam_db$adsl, c("USUBJID"), types = list(c("character", "factor")))
   assert_valid_var_pair(adam_db$adsl, adam_db$adlb, arm_var)
