@@ -1,7 +1,11 @@
 # lbt01 functions ----
 
 test_that("lbt01 functions with default argument value return expected result with test data", {
-  pre_data <- lbt01_pre(syn_data)
+  proc_data <- syn_data[c("adsl", "adlb")]
+  proc_data$adlb <- proc_data$adlb %>%
+    dplyr::mutate(PARAMCD = paste0(PARAMCD, "SI"))
+
+  pre_data <- lbt01_pre(proc_data)
   raw_res <- lbt01_main(pre_data)
   res <- cfbt01_post(raw_res)
   expect_snapshot(cat(export_as_txt(res, lpp = 200)))
@@ -12,7 +16,7 @@ test_that("lbt01 functions with default argument value return expected result wi
 test_that("lbt01 functions with row_split_var return expected result with test data", {
   skip_on_os("windows")
   pre_data <- lbt01_pre(syn_data)
-  raw_res <- lbt01_main(pre_data, row_split_var = "LBCAT")
+  raw_res <- lbt01_main(pre_data, row_split_var = "LBCAT", precision = list("ALT" = 0))
   res <- cfbt01_post(raw_res)
   expect_snapshot(cat(export_as_txt(res, lpp = 200)))
 })
