@@ -12,6 +12,7 @@ test_that("mng01 works as expected with default argument values", {
 })
 
 test_that("mng01 works as expected with custom argument values", {
+  skip_on_os("windows")
   withr::with_options(opts_partial_match_old, {
     col <- c(
       "B: Placebo" = "black",
@@ -50,6 +51,7 @@ test_that("mng01 works as expected with custom argument values", {
 # mng01 ----
 
 test_that("mng01 works as expected with custom color set", {
+  skip_on_os("windows")
   withr::with_options(opts_partial_match_old, {
     col <- c(
       "B: Placebo" = "black",
@@ -70,7 +72,30 @@ test_that("mng01 works as expected with custom color set", {
   })
 })
 
+test_that("mng01 works as expected with custom line type set", {
+  skip_on_os("windows")
+  withr::with_options(opts_partial_match_old, {
+    lty <- c(
+      "B: Placebo" = "99",
+      "A: Drug X" = "92",
+      "C: Combination" = "solid"
+    )
+    proc_data <- syn_data
+
+    res <- run(mng01, proc_data, dataset = "adlb", line_type = lty)
+    expect_list(res, len = 3, types = "ggplot")
+
+    res2 <- run(mng01, proc_data, dataset = "adlb", line_type = unname(lty))
+    expect_list(res, len = 3, types = "ggplot")
+
+    skip_on_ci()
+    vdiffr::expect_doppelganger("run mng01 with custom line type set", res[[1]])
+    vdiffr::expect_doppelganger("run mng01 with custom unnamed line type set", res2[[1]])
+  })
+})
+
 test_that("mng01 works with table = NULL", {
+  skip_on_os("windows")
   withr::with_options(opts_partial_match_old, {
     proc_data <- syn_data
     res <- run(mng01, proc_data, dataset = "adlb", table = NULL)
@@ -82,6 +107,7 @@ test_that("mng01 works with table = NULL", {
 })
 
 test_that("mng01 works with combination of x variables", {
+  skip_on_os("windows")
   withr::with_options(opts_partial_match_old, {
     proc_data <- syn_data
     res <- run(
@@ -99,6 +125,7 @@ test_that("mng01 works with combination of x variables", {
 })
 
 test_that("mng01 works with numeric x variable", {
+  skip_on_os("windows")
   withr::with_options(opts_partial_match_old, {
     proc_data <- syn_data
     proc_data$adlb$AVISITN[1:20] <- 10
@@ -119,6 +146,7 @@ test_that("mng01 works with numeric x variable", {
 })
 
 test_that("mng01 works with numeric jitter", {
+  skip_on_os("windows")
   withr::with_options(opts_partial_match_old, {
     proc_data <- syn_data
 
